import * as React from 'react';
import { defaults } from 'lodash';
import { connect } from 'react-redux';
import { createStructuredSelector, createSelector } from 'reselect';
export default function featureContent(options) {
  const {
    getFeatures,
    sortFeatures,
    getContent
  } = defaults({}, options, {
    getFeatures: state => state ? state.features : {},
    sortFeatures: features => Object.values(features)
  });
  const mapStateToProps = createStructuredSelector({
    features: createSelector(getFeatures, sortFeatures)
  });
  function mergeProps({
    features
  }, dispatchProps, {
    children,
    ...props
  }) {
    const content = [];
    features.forEach((feature, featureIndex) => {
      let featureContent = getContent(feature);
      if (featureContent == null) return;
      if (typeof featureContent === 'function') featureContent = featureContent(props);
      if (!Array.isArray(featureContent)) featureContent = [featureContent];
      featureContent.forEach((item, index) => {
        if ( /*#__PURE__*/React.isValidElement(item) && item.key == null) {
          item = /*#__PURE__*/React.cloneElement(item, {
            key: featureIndex + ':' + index
          });
        }
        content.push(item);
      });
    });
    return {
      children: children instanceof Function ? children(content) : /*#__PURE__*/React.createElement(React.Fragment, null, content)
    };
  }
  mergeProps.propTypes = {
    "features": PropTypes.arrayOf(function () {
      return (typeof Feature === "function" ? PropTypes.instanceOf(Feature).isRequired : PropTypes.any.isRequired).apply(this, arguments);
    }).isRequired
  };
  const FeatureContent = ({
    children
  }) => children;
  return connect(mapStateToProps, null, mergeProps)(FeatureContent);
}
featureContent.propTypes = {
  "getFeatures": PropTypes.func,
  "sortFeatures": PropTypes.func,
  "getContent": PropTypes.func.isRequired
};
import PropTypes from "prop-types";